print("import: 'pysal'")
import pysal

print("import: 'pysal.viz'")
import pysal.viz

print("import: 'pysal.explore'")
import pysal.explore

print("import: 'pysal.model'")
import pysal.model

print("import: 'pysal.lib'")
import pysal.lib

